Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var DefaultArguments = Arguments{
MaxCacheSize: 10_000,
}
DefaultArguments provides the default arguments for the loki.relabel component.
Functions ¶
This section is empty.
Types ¶
type Arguments ¶
type Arguments struct {
// Where the relabeled metrics should be forwarded to.
ForwardTo []loki.LogsReceiver `alloy:"forward_to,attr"`
// The relabelling rules to apply to each log entry before it's forwarded.
RelabelConfigs []*alloy_relabel.Config `alloy:"rule,block,optional"`
// The maximum number of items to hold in the component's LRU cache.
MaxCacheSize int `alloy:"max_cache_size,attr,optional"`
}
Arguments holds values which are used to configure the loki.relabel component.
func (*Arguments) SetToDefault ¶
func (a *Arguments) SetToDefault()
SetToDefault implements syntax.Defaulter.
type Component ¶
type Component struct {
// contains filtered or unexported fields
}
Component implements the loki.relabel component.
func (*Component) LiveDebugging ¶ added in v1.3.0
func (c *Component) LiveDebugging()
type Exports ¶
type Exports struct {
Receiver loki.LogsReceiver `alloy:"receiver,attr"`
Rules alloy_relabel.Rules `alloy:"rules,attr"`
}
Exports holds values which are exported by the loki.relabel component.
Click to show internal directories.
Click to hide internal directories.